epsilon_0 = 8.85418782e-12  # Permittivity of free space
mu_0 = 1.25663706e-6  # Permeability of free space
speed_of_light = 2.99792458e8  # Speed of light in vacuum
elementary_charge = 1.60217663e-19  # Elementary charge
mass_electron = 9.10938371e-31  # Electron mass
mass_proton = 1.67262193e-27  # Proton mass
boltzmann_constant = 1.380649e-23  # Boltzmann constant
